using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ComboBoxTest
{
   public partial class Form1 : Form
   {
      DataTable _dataTable;

      public Form1()
      {
         InitializeComponent();
         _dataTable = new DataTable();
         _dataTable.Columns.Add("Column One");
         _dataTable.Columns.Add("Column Two");
         _dataTable.Columns.Add("Column Three");

         _dataTable.Rows.Add("Value One", "Value Two", "Value Three");
         _dataTable.Rows.Add("Value Four", "Value Five", "Value Six");
         _dataTable.Rows.Add("Value Seven", "Value Eight", "Value Nine");

         button1.Click += new EventHandler(button1_Click);
         button2.Click += new EventHandler(button2_Click);
      }

      /*
       * In both cases below, the MCCB of Form2 should display "Value Four\Value Five"
       * in the text area because the selected index is being explicitly set to 1
       * after the datasource is changed (See Form2::multiColumnComboBox1_DataSourceChanged).
       * 
       * However, in the first case, the text area displays
       * "System.Data.DataRowView" (formatting not being used; see Form2::multiColumnComboBox1_SelectedIndexChanged)
       * 
       * and in the second case
       * 
       * "Value One\ValueTwo" (incorrect row data being used)
       * 
       * Is the selected indexd being reset internally after I set it?  Formatting issues aside, the
       * index always seem to be Zero.
       * 
       * Strangely, if the MCCB is opened, the correct index is selected/highlighted.
       */

      /*
       * This assigns the datasource of the MCCB before the 
       * parent form is shown.
       */
      void button1_Click(object sender, EventArgs e)
      {
         Form2 f2 = new Form2(_dataTable);
         f2.Show();
      }

      /*
       * This does not assign the datasource of the MCCB until after its 
       * parent form is shown.
       */
      void button2_Click(object sender, EventArgs e)
      {
         Form2 f2 = new Form2(null);
         f2.Show();
         f2.Table = _dataTable;
      }

      
   }
}